@@ -3,7 +3,7 @@ package Shipwright::Script::Delete;
 use strict;
 use warnings;
 
-use base qw/App::CLI::Command Class::Accessor::Fast Shipwright::Script/;
+use base qw/App::CLI::Command Shipwright::Base Shipwright::Script/;
 __PACKAGE__->mk_accessors(qw/unreferenced check_only/);
 
 use Shipwright;
